@@ -25,6 +25,10 @@ Contact: yuvraaj@gmail.com
 #include "QGVDbusServer.h"
 #endif
 
+#if MEEGO_HARMATTAN
+#include <QDeclarativeView>
+#endif
+
 OsDependent::OsDependent(QObject *parent) : QObject(parent)
 {
 }//OsDependent::OsDependent
@@ -150,14 +154,31 @@ OsDependent::setLongWork (QWidget *window, bool bSet /*= false*/)
 
 //! Initial height and width for different OSes.
 QRect
-OsDependent::getStartingSize ()
+OsDependent::getStartingSize (QWidget *w)
 {
+    Q_UNUSED(w);
+
     QRect rect;
 #if DESKTOP_OS
     rect.setWidth (250);
     rect.setHeight (400);
+    qDebug() << "Using desktop settings." << rect;
 #else
     rect = qApp->desktop()->screenGeometry ();
+
+#if defined(MEEGO_HARMATTAN)
+    if (NULL != w) {
+//        QDeclarativeView *view = (QDeclarativeView *) w;
+//        view->rotate(-90.0);
+//        view->translate(0, -rect.height());
+//
+//        QRect r(rect);
+//        rect.setWidth(r.height());
+//        rect.setHeight(r.width());
+    }
+#endif
+
+    qDebug() << "Using mobile settings." << rect;
 #endif
 
     return rect;
